package cn.kdan.pdf.tech.core.controller;

import cn.kdan.pdf.tech.core.model.Domain;
import cn.kdan.pdf.tech.core.service.DomainService;
import constant.CommonConstant;
import org.springframework.web.bind.annotation.*;
import pojo.ResultMap;
import utils.CommonUtils;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.List;


@RestController
@RequestMapping("/domain")
public class DomainController {

    @Resource
    private DomainService domainService;

    /**
     * 获取DNS的txt文件
     *
     * @return string
     */
    @GetMapping("/getDNSTxt")
    public ResultMap<String> getDNSTxt() {
        String txt = "PDF-Tech-Editor" + "-domain-verification=" + CommonUtils.generateId();
        return new ResultMap<>(CommonConstant.SUCCESS, CommonConstant.RESULT_SUCCESS, txt);
    }

    /**
     * 获取https验证文件
     *
     * @param response file
     */
    @GetMapping("/getHttpTxt")
    public void getHttpTxt(HttpServletResponse response) {
        String fileName = "PDF-Tech-Editor-domain-verification.txt";
        String content = "PDF-Tech-Editor-domain-verification=" + CommonUtils.generateId();

        response.setContentType("text/plain");
        response.setHeader("Content-Disposition", "attachment; filename=" + fileName);

        try (PrintWriter writer = response.getWriter()) {
            writer.print(content);
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * 获取域名列表
     *
     * @param directoryId 目录id
     * @return list
     */
    @GetMapping("/listByDirectoryId")
    public ResultMap<List<Domain>> listByDirectoryId(@RequestParam String directoryId) {
        List<Domain> domainList = domainService.listByDirectoryId(directoryId);
        return new ResultMap<>(CommonConstant.SUCCESS, CommonConstant.RESULT_SUCCESS, domainList);
    }

    /**
     * 获取域名列表
     *
     * @param verified 0 未验证 1 已验证
     * @return list
     */
    @GetMapping("/list")
    public ResultMap<List<Domain>> list(@RequestParam(required = false) String verified) {
        List<Domain> domainList = domainService.list(verified);
        return new ResultMap<>(CommonConstant.SUCCESS, CommonConstant.RESULT_SUCCESS, domainList);
    }

    /**
     * 删除域名
     *
     * @param domainId 域名id
     * @return string
     */
    @PostMapping("/delete")
    public ResultMap<String> delete(@RequestParam String domainId) {
        domainService.delete(domainId);
        return new ResultMap<>(CommonConstant.SUCCESS, CommonConstant.RESULT_SUCCESS);
    }

    /**
     * 创建域名
     *
     * @param verifyType 验证类型
     * @param name       域名
     * @return string
     */
    @PostMapping("/create")
    public ResultMap<String> create(@RequestParam String verifyType, @RequestParam String name) {
        domainService.create(verifyType, name);
        return new ResultMap<>(CommonConstant.SUCCESS, CommonConstant.RESULT_SUCCESS);
    }

    /**
     * 验证域名
     *
     * @param domainId    域名id
     * @param verifyCode  验证码
     * @param fileName    文件名
     * @param fileContent 文件内容
     * @return string
     */
    @PostMapping("/verify")
    public ResultMap<String> verify(@RequestParam String domainId, @RequestParam(required = false) String verifyCode,
                                    @RequestParam(required = false) String fileName, @RequestParam(required = false) String fileContent) {
        domainService.verify(domainId, verifyCode, fileName, fileContent);
        return new ResultMap<>(CommonConstant.SUCCESS, CommonConstant.RESULT_SUCCESS);
    }

    /**
     * 绑定域名
     *
     * @param domainId    域名id
     * @param directoryId 目录id
     * @return string
     */
    @PostMapping("/bind")
    public ResultMap<String> bind(@RequestParam String domainId, @RequestParam String directoryId) {
        domainService.bindDomain(domainId, directoryId);
        return new ResultMap<>(CommonConstant.SUCCESS, CommonConstant.RESULT_SUCCESS);
    }

}
